@@ -19,6 +19,8 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "secretstorage.h"
+#include "../internals/settings/802-11-wireless-security.h"
+#include "../internals/settings/802-1x.h"
 
 #include <KConfigGroup>
 #include <kwallet.h>
@@ -154,6 +156,18 @@ void SecretStorage::walletOpenedForRead(bool success)
                     if (i.next().key() != con->uuid())
                         continue;
 
+                    Knm::WirelessSecuritySetting * settingSecurity = static_cast<Knm::WirelessSecuritySetting *>(con->setting(Knm::Setting::WirelessSecurity));
+                    if (settingSecurity) {
+                        Knm::Security8021xSetting * setting8021x = static_cast<Knm::Security8021xSetting *>(con->setting(Knm::Setting::Security8021x));
+
+                        if (setting8021x) {
+                            if (settingSecurity->securityType() == Knm::WirelessSecuritySetting::EnumSecurityType::DynamicWep ||
+                                settingSecurity->securityType() == Knm::WirelessSecuritySetting::EnumSecurityType::WpaEap) {
+                                setting8021x->setEnabled(true); // needed for needSecrets() below, otherwise needSecrets() returns an empty list.
+                            }
+                        }
+                    }
+
                     QPair<QString,GetSecretsFlags> pair = i.value();
                     bool settingsFound = false;
                     foreach (Knm::Setting * setting, con->settings()) {
@@ -374,8 +388,9 @@ void SecretStorage::switchStorage(SecretStorageMode oldMode, SecretStorageMode n
             KConfigGroup configGroup(config, parts[1]);
             QMap<QString, QString> secrets;
             wallet->readMap(key, secrets);
-            foreach (const QString &secret, secrets.keys()) {
-                configGroup.writeEntry(secret, secrets.value(secret));
+            QMap<QString, QString>::ConstIterator it = secrets.constBegin();
+            for ( ; it != secrets.constEnd(); ++it) {
+                configGroup.writeEntry(it.key(), it.value());
             }
             wallet->removeEntry(key);
         }
